@@ -36,10 +36,12 @@ sub _build_scrubber {
 
   my %scrub_rules = (
     img => {
-      src   => qr{^http://},    # only URL with http://
+      src   => qr{^https?://},  # only URL with http://
       alt   => 1,               # alt attributes allowed
       align => 1,               # allow align on images
       style => 1,
+      width => 1,
+      height => 1,
       '*'   => 0,               # deny all others
     },
     style => 0,
@@ -51,6 +53,13 @@ sub _build_scrubber {
       href => 1,
       '*'  => 0,
     },
+    iframe => {
+      frameborder => 0,
+      scrolling   => 0,
+      seamless    => 0,
+      '*'         => 1,
+    },
+    centre => 0,
   );
 
   # Definitions for HTML::Scrub
@@ -86,26 +95,33 @@ sub _build_scrubber {
     'style'       => 1,
     'class'       => 0,
     'id'          => 0,
+    'frameborder' => 0,
+    'border'      => 0,
   );
 
   my $scrub = HTML::Scrubber->new;
   $scrub->rules(%scrub_rules);
   $scrub->default(1, \%scrub_def);
+  $scrub->script(0);
 
   return $scrub;
 }
 
 around 'clean_html' => sub {
   my $orig = shift;
-  my ($self, $html) = @_;
+  my $self = shift;
+  my ($html) = @_;
+
+  warn __PACKAGE__, '::clean_html' if $ENV{PERLANET_DEBUG};
+
   $html = $self->$orig($html);
   my $scrubbed = $self->scrubber->scrub($html);
-  return $html;
+  return $scrubbed;
 };
 
 =head1 AUTHOR
 
-Dave Cross, <dave@mag-sol.com>
+Dave Cross, <dave@perlhacks.com>
 
 =head1 COPYRIGHT AND LICENSE
 
