@@ -77,7 +77,8 @@ use YAML qw( LoadFile );
 use constant THIRTY_DAYS => 30 * 24 * 60 * 60;
 
 sub get_config_from_file {
-  my ($self, $file) = @_;
+  my $class = shift;
+  my ($file) = @_;
 
   open my $cfg_file, '<:encoding(UTF-8)', $file
     or croak "Cannot open file $file: $!";
